pygeodesy.ellipsoids.a_f2Tuple

Package pygeodesy :: Module ellipsoids :: Class a_f2Tuple |
[frames] | no frames]

# Class a_f2Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       a_f2Tuple

2-Tuple `(a, f)` specifying an ellipsoid by equatorial radius `a` in `meter` and scalar flattening `f`.

See Also: Class Ellipsoid2.

Instance Methods
ellipsoid(self, **name) Return an Ellipsoid for this 2-tuple `(a, f)`. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, a, f, **name) New a_f2Tuple ellipsoid specification. |

Properties
| b Get the polar radius (`meter`), a * (1 - f).
| f_ Get the inverse flattening (`scalar`), 1 / f == a / (a - b).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, a, f, **name) Static Method |
New a_f2Tuple ellipsoid specification. Arguments: `a` - Equatorial radius (`scalar` > 0). `f` - Flattening (`scalar` < 1, negative for prolate). `name` - Optional `name=NN` (`str`). Returns: a new object with type S, a subtype of T An a_f2Tuple`(a, f)`. Raises: `UnitError` - Invalid `a` or `f`. Overrides: object.__new__ Notes: `abs(f) <` EPS is forced to `f=0`, spherical. Negative `f` produces a prolate ellipsoid.

### ellipsoid (self, **name) |
Return an Ellipsoid for this 2-tuple `(a, f)`. Arguments: `name` - Optional `name=NN` (`str`). Raises: `NameError` - A registered `ellipsoid` with the same `name` already exists.

Property Details

### b Get the polar radius (`meter`), a * (1 - f). Get method: b(self) - Get the polar radius (`meter`), a * (1 - f). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### f_ Get the inverse flattening (`scalar`), 1 / f == a / (a - b). Get method: f_(self) - Get the inverse flattening (`scalar`), 1 / f == a / (a - b). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.